@@ -407,6 +407,9 @@ RESOURCENOTFOUND_DOMAINNORECORD = 'ResourceNotFound.DomainNoRecord'
 # 域名不存在或不匹配。
 RESOURCENOTFOUND_DOMAINNOTEXIST = 'ResourceNotFound.DomainNotExist'
 
+# 用户被禁用。
+RESOURCENOTFOUND_FORBIDSERVICE = 'ResourceNotFound.ForbidService'
+
 # 用户不支持此接口。
 RESOURCENOTFOUND_INVALIDUSER = 'ResourceNotFound.InvalidUser'
 
